<?php

namespace Drupal\commerce_zones_shipping\Plugin\Commerce\Condition;

use Drupal\commerce_zones\Plugin\Commerce\Condition\BaseZoneAddress;
use Drupal\Core\Entity\EntityInterface;

/**
 * Provides the shipping zone address condition.
 *
 * @CommerceCondition(
 *   id = "order_shipping_address_zone",
 *   label = @Translation("Shipping address zone"),
 *   category = @Translation("Customer"),
 *   entity_type = "commerce_order",
 *   weight = 10,
 * )
 */
class OrderShippingZoneAddress extends BaseZoneAddress {

  /**
   * {@inheritdoc}
   */
  public function evaluate(EntityInterface $entity) {
    $this->assertEntity($entity);
    /** @var \Drupal\commerce_order\Entity\OrderInterface $order */
    $order = $entity;
    $order_profiles = $order->collectProfiles();
    $shipping_profile = $order_profiles['shipping'] ?? NULL;
    if (!$shipping_profile || $shipping_profile->get('address')->isEmpty()) {
      return FALSE;
    }
    /** @var \Drupal\address\Plugin\Field\FieldType\AddressItem|null $address */
    $address = $shipping_profile->get('address')->first();
    if (!$address) {
      // The conditions can't be applied until the shipping address is known.
      return FALSE;
    }

    return $this->evaluateAddress($address, $this->configuration['zones']);
  }

}
